#
# spec file for package scim-tables
#
# Copyright (c) 2023 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           scim-tables
Version:        0.5.14.1
Release:        3.1
Summary:        Data Files for SCIM Generic Table Input Method Module
License:        GPL-2.0-or-later
Group:          System/I18n/Chinese
URL:            https://github.com/scim-im/scim-tables
Source:         https://github.com/scim-im/scim-tables/archive/%{name}-%{version}.tar.gz
#PATCH-FIX-SLE define G_GNUC_BEGIN/END_xx for glib < 2.32
Patch0:         G_GNUC_BEGIN_IGNORE_DEPRECATIONS.patch
#PATCH-FIX-UPSTREAM delete unused variables
Patch1:         unused-variable.patch
BuildRequires:  gcc-c++
BuildRequires:  intltool
BuildRequires:  libtool
BuildRequires:  scim-devel
Recommends:     %{name}-lang
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
%if 0%{?sles_version}
BuildRequires:  gtk2-devel
%else
BuildRequires:  gtk3-devel
%endif

%description
Data files for SCIM generic table input method module.

%package zh
Summary:        SCIM Chinese Data Files
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Provides:       locale(scim-tables:zh)

%description zh
This package includes SCIM table IM data files in Chinese.

The data files come from UNICON and XCIN.

%package ja
Summary:        SCIM Japanese Data Files
Group:          System/I18n/Japanese
Requires:       %{name} = %{version}
Provides:       locale(scim-tables:ja)

%description ja
This package includes the SCIM table IM data files in Japanese.

The data files come from UNICON.

%package ko
Summary:        SCIM Korean Data Files
Group:          System/I18n/Korean
Requires:       %{name} = %{version}
Provides:       locale(scim-tables:ko)

%description ko
This package includes SCIM table IM data files in Korean.

The data files come from UNICON.

%package additional
Summary:        Input Method data for non-CJK languages, including Russian etc
Group:          System/I18n/Chinese
Requires:       %{name} = %{version}
Provides:       locale(scim-tables:am;ar;bn;gu;hi;kn;ml;ne;pa;ru;ta;te;th;vi)

%description additional
Input Method data for non-CJK languages, including Russian etc. for the
scim-tables input method module.

%lang_package

%prep
%setup -q -n %{name}-%{name}-%{version}
%patch0 -p1
%patch1 -p1

%build
./bootstrap
%configure \
    --enable-debug
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install %{?_smp_mflags}
find %{buildroot} -name "*.a" -delete -print
find %{buildroot} -name "*.la" -delete -print
%find_lang %{name}

%files
%defattr(-,root,root)
%doc AUTHORS COPYING README ChangeLog
%{_bindir}/scim-make-table
%{_mandir}/man1/scim-make-table.1%{ext_man}
%{_scim_enginedir}/table.so
%{_scim_uidir}/table-imengine-setup.so
%{_scim_icondir}/table.png

%files zh
%defattr(-,root,root)
%doc tables/zh/README-CangJie.txt
%doc tables/zh/README-Erbi.txt
%doc tables/zh/README-Wu.txt
%{_scim_tabledir}/Array30.bin
%{_scim_tabledir}/CangJie.bin
%{_scim_tabledir}/CangJie3.bin
%{_scim_tabledir}/CangJie5.bin
%{_scim_tabledir}/Cantonese.bin
%{_scim_tabledir}/CantonHK.bin
%{_scim_tabledir}/CNS11643.bin
%{_scim_tabledir}/Dayi3.bin
%{_scim_tabledir}/Erbi.bin
%{_scim_tabledir}/Erbi-QS.bin
%{_scim_tabledir}/EZ-Big.bin
%{_scim_tabledir}/Jyutping.bin
%{_scim_tabledir}/Quick.bin
%{_scim_tabledir}/Simplex.bin
%{_scim_tabledir}/Stroke5.bin
%{_scim_tabledir}/Wu.bin
%{_scim_tabledir}/Wubi.bin
%{_scim_tabledir}/ZhuYin.bin
%{_scim_tabledir}/ZhuYin-Big.bin
%{_scim_tabledir}/Ziranma.bin
%{_scim_icondir}/Array30.png
%{_scim_icondir}/CangJie.png
%{_scim_icondir}/CangJie3.png
%{_scim_icondir}/Cantonese.png
%{_scim_icondir}/CantonHK.png
%{_scim_icondir}/CNS11643.png
%{_scim_icondir}/Dayi.png
%{_scim_icondir}/EZ.png
%{_scim_icondir}/Erbi-QS.png
%{_scim_icondir}/Erbi.png
%{_scim_icondir}/Jyutping.png
%{_scim_icondir}/Quick.png
%{_scim_icondir}/Simplex.png
%{_scim_icondir}/Stroke5.png
%{_scim_icondir}/Wu.png
%{_scim_icondir}/Wubi.png
%{_scim_icondir}/ZhuYin.png
%{_scim_icondir}/Ziranma.png

%files ja
%defattr(-,root,root)
%{_scim_tabledir}/HIRAGANA.bin
%{_scim_tabledir}/KATAKANA.bin
%{_scim_tabledir}/Nippon.bin
%{_scim_icondir}/HIRAGANA.png
%{_scim_icondir}/KATAKANA.png
%{_scim_icondir}/Nippon.png

%files ko
%defattr(-,root,root)
%{_scim_tabledir}/Hangul.bin
%{_scim_tabledir}/Hanja.bin
%{_scim_tabledir}/HangulRomaja.bin
%{_scim_icondir}/Hangul.png
%{_scim_icondir}/Hanja.png

%files additional
%defattr(-, root, root)
%{_scim_tabledir}/Amharic.bin
%{_scim_tabledir}/Arabic.bin
%{_scim_tabledir}/Nepali_Rom.bin
%{_scim_tabledir}/Nepali_Trad.bin
%{_scim_tabledir}/Yawerty.bin
%{_scim_tabledir}/Viqr.bin
%{_scim_tabledir}/IPA-X-SAMPA.bin
%{_scim_tabledir}/LaTeX.bin
%{_scim_tabledir}/Bengali-inscript.bin
%{_scim_tabledir}/Bengali-probhat.bin
%{_scim_tabledir}/Gujarati-inscript.bin
%{_scim_tabledir}/Gujarati-phonetic.bin
%{_scim_tabledir}/Hindi-inscript.bin
%{_scim_tabledir}/Hindi-phonetic.bin
%{_scim_tabledir}/Kannada-inscript.bin
%{_scim_tabledir}/Kannada-kgp.bin
%{_scim_tabledir}/Malayalam-inscript.bin
%{_scim_tabledir}/Malayalam-phonetic.bin
%{_scim_tabledir}/Punjabi-inscript.bin
%{_scim_tabledir}/Punjabi-jhelum.bin
%{_scim_tabledir}/Punjabi-phonetic.bin
%{_scim_tabledir}/Tamil-inscript.bin
%{_scim_tabledir}/Tamil-phonetic.bin
%{_scim_tabledir}/Tamil-remington.bin
%{_scim_tabledir}/Telugu-inscript.bin
%{_scim_tabledir}/Thai.bin
%{_scim_tabledir}/Translit.bin
%{_scim_tabledir}/Ukrainian-Translit.bin
%{_scim_tabledir}/Hindi-remington.bin
%{_scim_tabledir}/IPA-Kirshenbaum.bin
%{_scim_tabledir}/Marathi-remington.bin
%{_scim_tabledir}/Punjabi-remington.bin
%{_scim_tabledir}/RussianTraditional.bin
%{_scim_tabledir}/SmartCangJie6.bin
%{_scim_tabledir}/Tamil-tamil99.bin
%{_scim_tabledir}/Uyghur-Romanized.bin
%{_scim_tabledir}/Uyghur-Standard.bin
%{_scim_tabledir}/classicalhebrew.bin
%{_scim_tabledir}/greekpoly.bin
%{_scim_tabledir}/HebrewComputer.bin
%{_scim_tabledir}/RussianComputer.bin
%{_scim_icondir}/Amharic.png
%{_scim_icondir}/Arabic.png
%{_scim_icondir}/Nepali.png
%{_scim_icondir}/Yawerty.png
%{_scim_icondir}/Viqr.png
%{_scim_icondir}/IPA-X-SAMPA.png
%{_scim_icondir}/LaTeX.png
%{_scim_icondir}/Bengali-inscript.png
%{_scim_icondir}/Bengali-probhat.png
%{_scim_icondir}/Gujarati-inscript.png
%{_scim_icondir}/Gujarati-phonetic.png
%{_scim_icondir}/Hindi-inscript.png
%{_scim_icondir}/Hindi-phonetic.png
%{_scim_icondir}/Kannada-inscript.png
%{_scim_icondir}/Kannada-kgp.png
%{_scim_icondir}/Malayalam-inscript.png
%{_scim_icondir}/Malayalam-phonetic.png
%{_scim_icondir}/Punjabi-inscript.png
%{_scim_icondir}/Punjabi-jhelum.png
%{_scim_icondir}/Punjabi-phonetic.png
%{_scim_icondir}/Tamil-inscript.png
%{_scim_icondir}/Tamil-phonetic.png
%{_scim_icondir}/Tamil-remington.png
%{_scim_icondir}/Telugu-inscript.png
%{_scim_icondir}/Thai.png
%{_scim_icondir}/Hindi-remington.png
%{_scim_icondir}/Marathi-remington.png
%{_scim_icondir}/Punjabi-remington.png
%{_scim_icondir}/RussianTraditional.png
%{_scim_icondir}/SmartCangJie6.png
%{_scim_icondir}/Tamil-tamil99.png
%{_scim_icondir}/Translit.png
%{_scim_icondir}/Ukrainian-Translit.png
%{_scim_icondir}/Uyghur.png
%{_scim_icondir}/HebrewComputer.png
%{_scim_icondir}/RussianComputer.png

%files lang -f %{name}.lang
%defattr(-, root, root)

%changelog
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Fri Sep 18 2015 i@marguerite.su
- use macros from macros.scim
- add patch: G_GNUC_BEGIN_IGNORE_DEPRECATIONS.patch
  * define G_GNUC_BEGIN/END_IGNORE_DEPRECATIONS for glib < 2.32
- add patch: unused-variable.patch
  * delete unused variables
* Sun Mar 22 2015 p.drouand@gmail.com
- Update to version 0.5.14.1
  * ChangeLog has not been updated for this release
- Update home project and download Url
- Split out translaton files
- Add autoconf, automake and libtool buildrequire
* Tue Aug  6 2013 i@marguerite.su
- update to 0.5.13
  * Add modern Hebrew and Russian support, thanks to Ury Marshak
- no skim anymore
* Wed Sep 12 2012 hillwood@linuxfans.org
- update to 0.5.11, fixed gtk3 build by upstream.
- more tables support.
- remove old patches: these bugs which fixed by these patches have been
  fixed by upstream.
* Thu Jun  7 2012 swyear@gmail.com
- remove "Provides: locale(scim:zh)" from spec
* Tue Apr 20 2010 tiwai@suse.de
- disable build of skim for openSUSE-11.3
* Fri Sep 19 2008 mfabian@suse.de
- update to 0.5.8.
  • Added Swanalekha/Malayalam table.
  • Added Dutch translation.
  • Fix configure.ac to allow us to disable skim-support.
* Tue Nov 20 2007 mfabian@suse.de
- fix build with gcc 4.3.
* Wed Oct 11 2006 mfabian@suse.de
- update to 0.5.7 (Tamil-remington table added)
- fix build with scim 1.4.5
- fix-include-hints.diff removed (included upstream)
* Wed Mar 15 2006 mfabian@suse.de
- Bugzilla #158170: add "Provides: locale(skim:zh)" to
  scim-tables-skim sub-package.
* Tue Feb 28 2006 zsu@suse.de
- bug #153791; use semicolon instead of comma to split locale list.
* Fri Feb 24 2006 zsu@suse.de
- change Requires of scim-tables-{zh,ja,ko,additional} to %%{name} = %%{version}
- add Autoreqprov: on to scim-tables.
* Fri Feb 24 2006 zsu@suse.de
- add Provides: locale(scim:zh) to scim-tables
- add Provides: locale(scim-tables:zh) to scim-tables-zh
- add Provides: locale(scim-tables:ja) to scim-tables-ja
- add Provides: locale(scim-tables:ko) to scim-tables-ko
- add Provides: locale(scim-tables:am,ar,bn,gu,hi,kn,ml,ne,pa,ru,ta,te,th,vi) to scim-tables-additional
* Fri Jan 27 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Jan 25 2006 zsu@suse.de
- Update CangJie, ZhuYin and ZhuYin-Big tables to the latest cvs
  head version.
* Thu Jan 12 2006 mfabian@suse.de
- update to 0.5.6
* Wed Oct 12 2005 stbinner@suse.de
- fix wrong include hints for compilation against Qt 3.3.5
* Fri Aug 12 2005 mfabian@suse.de
- The setup plugin was not built. Omit the "autoreconf" to build
  the setup plugin as well. Thanks to LiuCougar.
* Fri Aug 12 2005 mfabian@suse.de
- update to 0.5.3.
* Thu Aug 11 2005 mfabian@suse.de
- update to 0.5.2.
* Thu Aug  4 2005 mfabian@suse.de
- Bugzilla #97962: add configure option "--enable-debug" to
  the .spec file.
* Wed Jun  8 2005 mfabian@suse.de
- update to 0.5.1.20050608.
  LaTeX and Wu input methods have been added.
- remove ipa-x-sampa.patch (now included).
* Fri Jun  3 2005 mfabian@suse.de
- update to 0.5.1.20050603.
* Mon Apr 25 2005 mfabian@suse.de
- update to 0.5.1.20050425.
- add IPA-X-SAMPA input method.
* Mon Feb 28 2005 mfabian@suse.de
- update to 0.5.1.
* Tue Feb 15 2005 mfabian@suse.de
- update to 0.5.0.20050215.
* Mon Jan 24 2005 mfabian@suse.de
- update to 0.5.0.20050124.
* Mon Jan 10 2005 mfabian@suse.de
- add gtk2-devel-packages to "# neededforbuild", without that the
  setup module is not built.
- add doc files.
* Mon Jan 10 2005 mfabian@suse.de
- update to 0.5.0.20050110.
* Mon Dec 13 2004 mfabian@suse.de
- Bugzilla #48811: include mail exchange with Jim Breen to
  the documentation. Professur Jim Breen gave explicit permission
  to use the Japanese readings from the KANJIDIC, KANJD212 and
  KANJDIDIC2 files for building data files for SCIM.
* Fri Sep  3 2004 mfabian@suse.de
- update to 0.4.3.
* Fri Aug 20 2004 mfabian@suse.de
- update to 0.4.2. Important update for Wubi.
* Fri Aug 13 2004 mfabian@suse.de
- update to 0.4.1.
* Thu Aug  5 2004 mfabian@suse.de
- update to 0.4.0.
* Wed Apr 28 2004 mfabian@suse.de
- remove "BuildArch: noarch", the author Zhe Su <zsu@novell.com>
  says that the new version should be arch dependent because it
  now stores the memory image directly.
* Tue Apr 27 2004 mfabian@suse.de
- update to 0.3.5.
* Fri Apr  2 2004 mfabian@suse.de
- change URL of source file to it's current location.
* Thu Feb 26 2004 mfabian@suse.de
- update to 0.3.2.
* Tue Dec  9 2003 mfabian@suse.de
- update to 0.3.0.
- remove scim-server-table from neededforbuild (has been merged
  into main scim package.
- don't build as root.
* Fri Jul  4 2003 mfabian@suse.de
- new package: version 0.2.2.
- adapt .spec file for SuSE.
* Wed Feb 26 2003 James Su <suzhe@tsinghua.org.cn>
- updated table format according to SCIM 0.3.1.
* Mon Nov  4 2002 James Su <suzhe@tsinghua.org.cn>
- Initial release.
